RobotClock

Struct RobotClock 

pub struct RobotClock { /* private fields */ }
A running Robot clock. The clock is a monotonic clock that starts at an arbitrary reference time. It is clone resilient, ie a clone will be the same clock, even when mocked.

Implementations

Source

impl RobotClock

pub fn new() -> Self

Creates a RobotClock using now as its reference time. It will start at 0ns incrementing monotonically. This uses the std System Time as a reference clock.

pub fn new_with_rtc( read_rtc_ns: impl Fn() -> u64 + Send + Sync + 'static, sleep_ns: impl Fn(u64) + Send + Sync + 'static, ) -> Self

Builds a RobotClock using a reference RTC clock to calibrate with. This is mandatory to use with the no-std platforms as we have no idea where to find a reference clock.

pub fn from_ref_time(ref_time_ns: u64) -> Self

Builds a monotonic clock starting at the given reference time.

pub fn from_ref_time_with_rtc( read_rtc_ns: fn() -> u64, sleep_ns: fn(u64), ref_time_ns: u64, ) -> Self

Overrides the RTC with a custom implementation, should be the same as the new_with_rtc.

pub fn mock() -> (Self, RobotClockMock)

Build a fake clock with a reference time of 0. The RobotMock interface enables you to control all the clones of the clock given.

pub fn now(&self) -> CuTime

Now returns the time that passed since the reference time, usually the start time. It is a monotonically increasing value.

pub fn recent(&self) -> CuTime

A less precise but quicker time